@@ -8,6 +8,27 @@ use File::Path ();
 use File::Basename ();
 use Fatal qw(open close unlink);
 use Data::Dumper;
+use File::Glob qw(bsd_glob);
+use Carp;
+
+# use the system version of a module if present; in theory this could lead to
+# compatibility problems (if the latest version of one of the dependencies,
+# installed in @INC is incompatible with the bundled version of a module)
+sub _load_bundled_modules {
+    # the load order is important: all dependencies must be loaded
+    # before trying to load a module
+    require inc::latest;
+
+    inc::latest->import( $_ )
+        foreach qw(version
+                   Locale::Maketext::Simple
+                   Params::Check
+                   Module::Load
+                   Module::Load::Conditional
+                   IPC::Cmd
+                   Archive::Extract
+                   File::Fetch);
+}
 
 sub ACTION_build {
     my $self = shift;
@@ -69,9 +90,20 @@ sub ACTION_install {
     $self->install_system_wxwidgets;
 }
 
-sub ACTION_distcheck {
-    my $self = shift;
-    my $data = $self->notes( 'build_data' );
+sub _check_data_file {
+    my( $self, $file, $manifest ) = @_;
+
+    require File::Spec::Unix;
+
+    my $data = do {
+        package main;
+        our( $TYPE, $URL );
+        local $TYPE = 'dummy';
+        local $URL = 'dummy';
+
+        do $file;
+    };
+    die "Unable to load data file '$file': $@" unless $data;
 
     foreach my $p ( qw(msw mac unix) ) {
         next unless exists $data->{$p};
@@ -81,13 +113,40 @@ sub ACTION_distcheck {
 
             foreach my $f ( @{$data->{$p}{$c}} ) {
                 my $file = File::Spec->catfile( 'patches', $f );
+                my $manifest_file = File::Spec::Unix->catfile( 'patches', $f );
 
-                warn 'Missing patch file: ', $file, "\n" unless -f $file;
+                die 'Missing patch file: ', $file, "\n" unless -f $file;
+                die 'Patch file ', $file, ' not in MANIFEST'
+                  unless exists $manifest->{$manifest_file};
             }
         }
     }
+}
+
+sub _check_data_files {
+    my( $self ) = @_;
+
+    require ExtUtils::Manifest;
+    my $files = ExtUtils::Manifest::maniread();
+
+    foreach my $data ( grep m{^patches/data}, keys %$files ) {
+        print "Checking $data\n";
+        $self->_check_data_file( $data, $files );
+    }
+}
+
+sub ACTION_distcheck {
+    my $self = shift;
 
     $self->SUPER::ACTION_distcheck;
+    $self->_check_data_files;
+}
+
+sub ACTION_dist {
+    my $self = shift;
+
+    $self->_check_data_files;
+    $self->SUPER::ACTION_dist;
 }
 
 sub awx_key {
@@ -238,7 +297,7 @@ sub fetch_wxwidgets {
     my $self = shift;
 
     return if -f $self->notes( 'build_data' )->{data}{archive};
-    require File::Fetch;
+    $self->_load_bundled_modules;
 
     print "Fetching wxWidgets...\n";
     print "fetching from: ", $self->notes( 'build_data' )->{data}{url}, "\n";
@@ -256,7 +315,7 @@ sub extract_wxwidgets {
 
     print "Extracting wxWidgets...\n";
 
-    require Archive::Extract;
+    $self->_load_bundled_modules;
     $Archive::Extract::PREFER_BIN = 1;
     my $ae = Archive::Extract->new( archive => $archive );
 
@@ -365,6 +424,13 @@ sub awx_wx_patches {
                @{$data->{$toolkit}{$unicode}};
 }
 
+sub awx_version_type {
+    my $self = shift;
+    my $versiontype = ( $self->notes( 'build_data' )->{data}{version} =~ /^2\.(6|7|8)/ )
+        ? 2 : 3;
+    return $versiontype;
+}
+
 sub awx_get_name {
     my( $self, %args ) = @_;
     my $e = sub { defined $_[0] ? ( $_[0] ) : () };
@@ -394,7 +460,10 @@ sub awx_path_search {
 
     foreach my $d ( File::Spec->path ) {
         my $full = File::Spec->catfile( $d, $file );
-        return $full if -f $full;
+        # we are gonna use glob() to accept wildcards
+        foreach my $f ( bsd_glob( $full ) ) {
+            return $f if -f $f;
+        }
     }
 
     return;
